# SearchSource: arXiv.org

## Add the search source

### API

```
colrev search -a colrev.arxiv -p "https://arxiv.org/search/?query=fitbit&searchtype=all&abstracts=show&order=-announced_date_first&size=50"
```

## Links

- [arXiv](https://arxiv.org/)
